@@ -130,8 +130,13 @@ class ProfilingSession(object):
         context = (None if not self.user_context_fn else
                    self.user_context_fn(conn, clause, multiparams, params, results))
 
+        try:
+            text = clause.compile(dialect=conn.engine.dialect)
+        except AttributeError:
+            text = clause
+
         # add the querystats to the collector
-        self.collect_fn(QueryStats(clause, traceback.extract_stack()[:-1], duration, context))
+        self.collect_fn(QueryStats(text, traceback.extract_stack()[:-1], duration, context))
 
     def collect(self):
         """ Return all queries collected by this profiling session so far.
@@ -287,7 +292,7 @@ def report(statistics, filename=None, template="report.mako", **kwargs):
     # create the template lookup
     # (we need this for extensions inheriting the base template)
     tmpl_dir = os.path.join(os.path.dirname(__file__), "templates")
-    lookup = mako.lookup.TemplateLookup(tmpl_dir)
+    lookup = mako.lookup.TemplateLookup(tmpl_dir, default_filters=['unicode', 'h']) # mako fixes unicode -> str on py3k
 
     # render the template
     html = lookup.get_template(template).render(
